@@ -5,16 +5,20 @@ if __name__ == "__main__":
     from crypto import CryptoHandler
     from exceptions import (ColumnDataDoesNotFit, ColumnNotFoundError, 
                            DataWasNotGiven, DataWasNotGivenError)
+    from utils import typeassert
 else:
     from .gitee import GiteeRepo
     from .urlparse import URL
     from .crypto import CryptoHandler
     from .exceptions import (ColumnDataDoesNotFit, ColumnNotFoundError,
                             DataWasNotGiven, DataWasNotGivenError)
+    from .utils import typeassert
 
 import json, warnings
+from typing import Union
 
-def model_to_data(model=None):
+@typeassert
+def model_to_data(model: Union[list, tuple]):
     return tuple([i.data if hasattr(i, "data") else i for i in model])
 
 class table_objects:
@@ -286,13 +290,4 @@ class SqleeTable:
     def delete_all(self):
         answer = self.repo.drop_folder(path=self.name)
         del self
-        return answer
-
-if __name__ == "__main__":
-    pass
-    #repo = GiteeRepo(token="1895956f770eb0e4d08013ee4b753203", user="fu050409", repo="TEST_API")
-    #table = SqleeTable(
-    #    name="Table",
-    #    repo = repo
-    #    )
-    #print(table.columns[0].datas[0].data)
\ No newline at end of file
+        return answer
\ No newline at end of file
